@@ -48,6 +48,7 @@
 #include <libtracker-common/tracker-statement-list.h>
 #include <libtracker-common/tracker-ontology.h>
 #include <libtracker-common/tracker-utils.h>
+#include <libtracker-common/tracker-type-utils.h>
 
 #include "tracker-albumart.h"
 #include "tracker-main.h"
@@ -88,11 +89,11 @@ typedef struct {
 	gchar *title;
 	gchar *artist;
 	gchar *album;
-	gchar *year;
+	gchar *recording_time;
 	gchar *comment;
-	gchar *trackno;
 	gchar *genre;
 	gchar *encoding;
+	gint   track_number;
 } id3tag;
 
 typedef struct {
@@ -131,6 +132,8 @@ typedef struct {
 	gchar         *publisher;
 	gchar         *comment;
 
+	gint           track_number;
+
 	unsigned char *albumartdata;
 	size_t         albumartsize;
 	gchar         *albumartmime;
@@ -681,7 +684,7 @@ get_id3 (const gchar *data,
 	GString *s;
 	gboolean encoding_was_found;
 #endif /* HAVE_ENCA */
-	gchar *encoding;
+	gchar *encoding, *year;
 	const gchar *pos;
 
 	if (!data) {
@@ -730,20 +733,24 @@ get_id3 (const gchar *data,
 	id3->album = g_convert (pos, 30, "UTF-8", encoding, NULL, NULL, NULL);
 
 	pos += 30;
-	id3->year = g_convert (pos, 4, "UTF-8", encoding, NULL, NULL, NULL);
+	year = g_convert (pos, 4, "UTF-8", encoding, NULL, NULL, NULL);
+	if (atoi (year) > 0) {
+		id3->recording_time = tracker_date_format (year);
+	}
+	g_free (year);
 
 	pos += 4;
 
 	if (pos[28] != 0) {
 		id3->comment = g_convert (pos, 30, "UTF-8", encoding, NULL, NULL, NULL);
-		id3->trackno = NULL;
+		id3->track_number = 0;
 	} else {
 		gchar buf[5];
 
 		id3->comment = g_convert (pos, 28, "UTF-8", encoding, NULL, NULL, NULL);
 
 		snprintf (buf, 5, "%d", pos[29]);
-		id3->trackno = g_strdup (buf);
+		id3->track_number = atoi (buf);
 	}
 
 	pos += 30;
@@ -1177,6 +1184,7 @@ get_id3v24_tags (const gchar *data,
 
 			if (!tracker_is_empty_string (word)) {
 				g_strstrip (word);
+				g_free (tag->comment);
 				tag->comment = word;
 			} else {
 				g_free (word);
@@ -1216,7 +1224,8 @@ get_id3v24_tags (const gchar *data,
 				tag->copyright = word;
 				break;
 			case ID3V24_TDRC:
-				tag->recording_time = word;
+				tag->recording_time = tracker_date_format (word);
+				g_free (word);
 				break;
 			case ID3V24_TDRL:
 				tag->release_time = word;
@@ -1235,6 +1244,7 @@ get_id3v24_tags (const gchar *data,
 				break;
 			case ID3V24_TLEN:
 				tag->length = atoi (word) / 1000;
+				g_free (word);
 				break;
 			case ID3V24_TPE1:
 				tag->performer1 = word;
@@ -1259,9 +1269,13 @@ get_id3v24_tags (const gchar *data,
 				break;
 			}
 			case ID3V24_TYER:
-				tag->recording_time = word;
+				if (atoi (word) > 0) {
+					tag->recording_time = tracker_date_format (word);
+				}
+				g_free (word);
 				break;
 			default:
+				g_free (word);
 				g_warn_if_reached ();
 			}
 		}
@@ -1375,10 +1389,12 @@ get_id3v23_tags (const gchar *data,
 
 			if (!tracker_is_empty_string (word)) {
 				g_strstrip (word);
+				g_free (tag->comment);
 				tag->comment = word;
 			} else {
 				g_free (word);
 			}
+
 			break;
 		}
 		default:
@@ -1427,6 +1443,7 @@ get_id3v23_tags (const gchar *data,
 				break;
 			case ID3V24_TLEN:
 				tag->length = atoi (word) / 1000;
+				g_free (word);
 				break;
 			case ID3V24_TPE1:
 				tag->performer1 = word;
@@ -1451,9 +1468,13 @@ get_id3v23_tags (const gchar *data,
 				break;
 			}
 			case ID3V24_TYER:
-				tag->recording_time = word;
+				if (atoi (word) > 0) {
+					tag->recording_time = tracker_date_format (word);
+				}
+				g_free (word);
 				break;
 			default:
+				g_free (word);
 				g_warn_if_reached ();
 			}
 		}
@@ -1542,6 +1563,7 @@ get_id3v20_tags (const gchar *data,
 			case ID3V2_TCO:
 			{
 				gint genre;
+
 				if (get_genre_number (word, &genre)) {
 					g_free (word);
 					word = g_strdup (get_genre_name (genre));
@@ -1552,12 +1574,15 @@ get_id3v20_tags (const gchar *data,
 				} else {
 					g_free (word);
 				}
+
+				break;
 			}
 			case ID3V2_TCR:
 				tag->copyright = word;
 				break;
 			case ID3V2_TLE:
 				tag->length = atoi (word) / 1000;
+				g_free (word);
 				break;
 			case ID3V2_TPB:
 				tag->publisher = word;
@@ -1581,9 +1606,13 @@ get_id3v20_tags (const gchar *data,
 				tag->text = word;
 				break;
 			case ID3V2_TYE:
-				tag->recording_time = word;
+				if (atoi (word) > 0) {
+					tag->recording_time = tracker_date_format (word);
+				}
+				g_free (word);
 				break;
 			default:
+				g_free (word);
 				g_warn_if_reached ();
 			}
 		}
@@ -1927,11 +1956,13 @@ extract_mp3 (const gchar *uri,
 	                                   filedata.id3v22_info.content_type,
 	                                   filedata.id3v22_info.title1,
 	                                   filedata.id3v1_info.genre);
-	filedata.recording_time = tracker_coalesce (5, filedata.id3v24_info.recording_time,
+	filedata.recording_time = tracker_coalesce (7, filedata.id3v24_info.recording_time,
 	                                            filedata.id3v24_info.release_time,
 	                                            filedata.id3v23_info.recording_time,
+	                                            filedata.id3v23_info.release_time,
 	                                            filedata.id3v22_info.recording_time,
-	                                            filedata.id3v1_info.year);
+	                                            filedata.id3v22_info.release_time,
+	                                            filedata.id3v1_info.recording_time);
 	filedata.publisher = tracker_coalesce (3, filedata.id3v24_info.publisher,
 	                                       filedata.id3v23_info.publisher,
 	                                       filedata.id3v22_info.publisher);
@@ -1949,6 +1980,16 @@ extract_mp3 (const gchar *uri,
 	                                     filedata.id3v22_info.comment,
 	                                     filedata.id3v1_info.comment);
 
+	if (filedata.id3v24_info.track_number != 0) {
+		filedata.track_number = filedata.id3v24_info.track_number;
+	} else if (filedata.id3v23_info.track_number != 0) {
+		filedata.track_number = filedata.id3v23_info.track_number;
+	} else if (filedata.id3v22_info.track_number != 0) {
+		filedata.track_number = filedata.id3v22_info.track_number;
+	} else if (filedata.id3v1_info.track_number != 0) {
+		filedata.track_number = filedata.id3v1_info.track_number;
+	}
+
 	if (!tracker_is_blank_string (filedata.performer)) {
 		filedata.performer_uri = tracker_uri_printf_escaped ("urn:artist:%s", filedata.performer);
 		tracker_sparql_builder_subject_iri (metadata, filedata.performer_uri);
@@ -2033,6 +2074,11 @@ extract_mp3 (const gchar *uri,
 	}
 	g_free (filedata.publisher);
 
+	if (filedata.track_number > 0) {
+		tracker_sparql_builder_predicate (metadata, "nmm:trackNumber");
+		tracker_sparql_builder_object_int64 (metadata, filedata.track_number);
+	}
+
 	/* Get mp3 stream info */
 	mp3_parse (buffer, buffer_size, audio_offset, uri, metadata, &filedata);
 
