@@ -44,11 +44,11 @@
 #include <libtracker-db/tracker-db-manager.h>
 #include <libtracker-db/tracker-db-dbus.h>
 
-#include "tracker-dbus.h"
 #include "tracker-config.h"
 #include "tracker-marshal.h"
 #include "tracker-miner-applications.h"
 #include "tracker-miner-files.h"
+#include "tracker-thumbnailer.h"
 
 #define ABOUT								  \
 	"Tracker " PACKAGE_VERSION "\n"
@@ -63,6 +63,7 @@
 static GMainLoop    *main_loop;
 static GSList       *miners;
 static GSList       *current_miner;
+static gboolean      finished_miners;
 
 static gboolean      version;
 static gint	     verbosity = -1;
@@ -183,6 +184,10 @@ initialize_priority (void)
 static void
 miner_handle_next (void)
 {
+        if (finished_miners) {
+                return;
+        }
+
         if (!current_miner) {
                 current_miner = miners;
         } else {
@@ -190,6 +195,10 @@ miner_handle_next (void)
         }
 
         if (!current_miner) {
+                finished_miners = TRUE;
+
+                g_message ("All miners are now finished");
+                tracker_thumbnailer_queue_send ();
                 return;
         }
 
@@ -216,16 +225,6 @@ miner_finished_cb (TrackerMinerFS *fs,
         miner_handle_next ();
 }
 
-static void
-daemon_availability_changed_cb (const gchar *name,
-                                gboolean     available,
-                                gpointer     user_data)
-{
-        if (!available) {
-                /* tracker_indexer_stop (TRACKER_INDEXER (user_data)); */
-        }
-}
-
 int
 main (gint argc, gchar *argv[])
 {
@@ -291,12 +290,6 @@ main (gint argc, gchar *argv[])
 	/* Make sure we initialize DBus, this shows we are started
 	 * successfully when called upon from the daemon.
 	 */
-#if 0
-	if (!tracker_dbus_init ()) {
-		return EXIT_FAILURE;
-	}
-#endif
-
 	tracker_log_init (tracker_config_get_verbosity (config),
                           &log_filename);
 	g_print ("Starting log:\n  File:'%s'\n", log_filename);
@@ -326,6 +319,8 @@ main (gint argc, gchar *argv[])
 	storage = NULL;
 #endif
 
+        tracker_thumbnailer_init ();
+
         /* Create miner for applications */
         miner_applications = tracker_miner_applications_new ();
         miners = g_slist_append (miners, miner_applications);
@@ -359,6 +354,7 @@ main (gint argc, gchar *argv[])
         g_slist_foreach (miners, (GFunc) g_object_unref, NULL);
         g_slist_free (miners);
         
+        tracker_thumbnailer_shutdown ();
 	tracker_log_shutdown ();
 
 	g_print ("\nOK\n\n");
