@@ -115,7 +115,9 @@ test_sparql_query (gconstpointer test_data)
 
 	/* load data set */
 	data_filename = g_strconcat (data_prefix, ".ttl", NULL);
+	tracker_data_begin_transaction ();
 	tracker_turtle_reader_load (data_filename, &error);
+	tracker_data_commit_transaction ();
 	g_assert (error == NULL);
 
 	query_filename = g_strconcat (test_prefix, ".rq", NULL);
